==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/LoadBalancerStatusFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface LoadBalancerStatusFluent<A extends io.fabric8.kubernetes.api.model.LoadBalancerStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToIngress(java.lang.Integer index,io.fabric8.kubernetes.api.model.LoadBalancerIngress item);
  public A setToIngress(java.lang.Integer index,io.fabric8.kubernetes.api.model.LoadBalancerIngress item);
  public A addToIngress(io.fabric8.kubernetes.api.model.LoadBalancerIngress... items);
  public A addAllToIngress(java.util.Collection<io.fabric8.kubernetes.api.model.LoadBalancerIngress> items);
  public A removeFromIngress(io.fabric8.kubernetes.api.model.LoadBalancerIngress... items);
  public A removeAllFromIngress(java.util.Collection<io.fabric8.kubernetes.api.model.LoadBalancerIngress> items);
  public A removeMatchingFromIngress(java.util.function.Predicate<io.fabric8.kubernetes.api.model.LoadBalancerIngressBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildIngress instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.LoadBalancerIngress> getIngress();
  public java.util.List<io.fabric8.kubernetes.api.model.LoadBalancerIngress> buildIngress();
  public io.fabric8.kubernetes.api.model.LoadBalancerIngress buildIngress(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.LoadBalancerIngress buildFirstIngress();
  public io.fabric8.kubernetes.api.model.LoadBalancerIngress buildLastIngress();
  public io.fabric8.kubernetes.api.model.LoadBalancerIngress buildMatchingIngress(java.util.function.Predicate<io.fabric8.kubernetes.api.model.LoadBalancerIngressBuilder> predicate);
  public java.lang.Boolean hasMatchingIngress(java.util.function.Predicate<io.fabric8.kubernetes.api.model.LoadBalancerIngressBuilder> predicate);
  public A withIngress(java.util.List<io.fabric8.kubernetes.api.model.LoadBalancerIngress> ingress);
  public A withIngress(io.fabric8.kubernetes.api.model.LoadBalancerIngress... ingress);
  public java.lang.Boolean hasIngress();
  public io.fabric8.kubernetes.api.model.LoadBalancerStatusFluent.IngressNested<A> addNewIngress();
  public io.fabric8.kubernetes.api.model.LoadBalancerStatusFluent.IngressNested<A> addNewIngressLike(io.fabric8.kubernetes.api.model.LoadBalancerIngress item);
  public io.fabric8.kubernetes.api.model.LoadBalancerStatusFluent.IngressNested<A> setNewIngressLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.LoadBalancerIngress item);
  public io.fabric8.kubernetes.api.model.LoadBalancerStatusFluent.IngressNested<A> editIngress(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.LoadBalancerStatusFluent.IngressNested<A> editFirstIngress();
  public io.fabric8.kubernetes.api.model.LoadBalancerStatusFluent.IngressNested<A> editLastIngress();
  public io.fabric8.kubernetes.api.model.LoadBalancerStatusFluent.IngressNested<A> editMatchingIngress(java.util.function.Predicate<io.fabric8.kubernetes.api.model.LoadBalancerIngressBuilder> predicate);
  public interface IngressNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.LoadBalancerIngressFluent<io.fabric8.kubernetes.api.model.LoadBalancerStatusFluent.IngressNested<N>>{
    public N and();
    public N endIngress();
    
  }
  
}

==> kubernetes-model-core-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/LoadBalancerStatusFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface LoadBalancerStatusFluent<A extends io.fabric8.kubernetes.api.model.LoadBalancerStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToIngress(java.lang.Integer index,io.fabric8.kubernetes.api.model.LoadBalancerIngress item);
  public A setToIngress(java.lang.Integer index,io.fabric8.kubernetes.api.model.LoadBalancerIngress item);
  public A addToIngress(io.fabric8.kubernetes.api.model.LoadBalancerIngress... items);
  public A addAllToIngress(java.util.Collection<io.fabric8.kubernetes.api.model.LoadBalancerIngress> items);
  public A removeFromIngress(io.fabric8.kubernetes.api.model.LoadBalancerIngress... items);
  public A removeAllFromIngress(java.util.Collection<io.fabric8.kubernetes.api.model.LoadBalancerIngress> items);
  public A removeMatchingFromIngress(java.util.function.Predicate<io.fabric8.kubernetes.api.model.LoadBalancerIngressBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildIngress instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.LoadBalancerIngress> getIngress();
  public java.util.List<io.fabric8.kubernetes.api.model.LoadBalancerIngress> buildIngress();
  public io.fabric8.kubernetes.api.model.LoadBalancerIngress buildIngress(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.LoadBalancerIngress buildFirstIngress();
  public io.fabric8.kubernetes.api.model.LoadBalancerIngress buildLastIngress();
  public io.fabric8.kubernetes.api.model.LoadBalancerIngress buildMatchingIngress(java.util.function.Predicate<io.fabric8.kubernetes.api.model.LoadBalancerIngressBuilder> predicate);
  public java.lang.Boolean hasMatchingIngress(java.util.function.Predicate<io.fabric8.kubernetes.api.model.LoadBalancerIngressBuilder> predicate);
  public A withIngress(java.util.List<io.fabric8.kubernetes.api.model.LoadBalancerIngress> ingress);
  public A withIngress(io.fabric8.kubernetes.api.model.LoadBalancerIngress... ingress);
  public java.lang.Boolean hasIngress();
  public io.fabric8.kubernetes.api.model.LoadBalancerStatusFluent.IngressNested<A> addNewIngress();
  public io.fabric8.kubernetes.api.model.LoadBalancerStatusFluent.IngressNested<A> addNewIngressLike(io.fabric8.kubernetes.api.model.LoadBalancerIngress item);
  public io.fabric8.kubernetes.api.model.LoadBalancerStatusFluent.IngressNested<A> setNewIngressLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.LoadBalancerIngress item);
  public io.fabric8.kubernetes.api.model.LoadBalancerStatusFluent.IngressNested<A> editIngress(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.LoadBalancerStatusFluent.IngressNested<A> editFirstIngress();
  public io.fabric8.kubernetes.api.model.LoadBalancerStatusFluent.IngressNested<A> editLastIngress();
  public io.fabric8.kubernetes.api.model.LoadBalancerStatusFluent.IngressNested<A> editMatchingIngress(java.util.function.Predicate<io.fabric8.kubernetes.api.model.LoadBalancerIngressBuilder> predicate);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface IngressNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.LoadBalancerIngressFluent<io.fabric8.kubernetes.api.model.LoadBalancerStatusFluent.IngressNested<N>>{
    public N and();
    public N endIngress();
    
  }
  
}
